==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/it/main.php <==
<?php

global $language;
$language = array (

'filenotexist'		=>	'Il file non esiste.  Contatta l\'amministratore di Flyspray per questo progetto.',
'showtask'			=>	'Mostra il task',
'go'				=>	'Vai!',
'opentaskanon'		=>	'Apri un nuovo task come anonimo',
'register'			=>	'Registra come un nuovo utente',
'loggedinas'		=>	'Connesso come',
'mytasks'			=>	'I miei task',
'addnewtask'		=>	'Aggiungi un nuovo task',
'editmydetails'		=>	'Modifica i miei dati',
'changepassword'	=>	'Cambia Password',
'logout'			=>	'Logout',
'options'			=>	'Opzioni',
'usersandgroups'	=>	'Utenti &amp; Gruppi',
'tasktypes'			=>	'Tipi di Task',
'categories'		=>	'Categorie',
'operatingsystems'	=>	'Sistemi Operativi',
'resolutions'		=>	'Soluzioni',
'versions'			=>	'Versioni',
'severities'		=>	'Gravita\'',
'disabledaccount'	=>	'La tua utenza e\' stato disabilitato!<br>Disconnessione immediata...',
'poweredby'			=>	'Powered by Flyspray',

// Added in version 0.9.5

'selectproject'		=>	'Lista dei task per il progetto:',
'show'				=>	'Mostra',
'projects'			=>	'Progetti',
'adminmenu'			=>	'Menu di amministrazione',

// Added in version 0.9.6
'duplicated'		=>	'Azione ripetuta. Redirect alla pagina principale.',
'allprojects'       =>	'Tutti i progetti',
'selectproject'		=>	'per il progettot:',
'tasksall'          =>  'Tutti i task',
'tasksassigned'     =>  'Tasks a me assegnati',
'tasksreported'     =>  'Tasks da me riportati',
'taskswatched'      =>  'Tasks che controllo',
'lastsearch'   =>  'Ultima ricerca'

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/it/main.php <==
<?php

global $language;
$language = array (

'filenotexist'		=>	'Il file non esiste.  Contatta l\'amministratore di Flyspray per questo progetto.',
'showtask'			=>	'Mostra il task',
'now'			=>	'Ora',
'go'				=>	'Vai!',
'opentaskanon'		=>	'Apri un nuovo task come anonimo',
'register'			=>	'Registra come un nuovo utente',
'loggedinas'		=>	'Connesso come',
'mytasks'			=>	'I miei task',
'addnewtask'		=>	'Aggiungi un nuovo task',
'reports'		=>	'Reports',
'editmydetails'		=>	'Modifica i miei dati',
'changepassword'	=>	'Cambia Password',
'logout'			=>	'Logout',
'options'			=>	'Opzioni',
'usersandgroups'	=>	'Utenti &amp; Gruppi',
'tasktypes'			=>	'Tipi di Task',
'categories'		=>	'Categorie',
'operatingsystems'	=>	'Sistemi Operativi',
'resolutions'		=>	'Soluzioni',
'versions'			=>	'Versioni',
'severities'		=>	'Gravita\'',
'disabledaccount'	=>	'La tua utenza e\' stato disabilitato!<br>Disconnessione immediata...',
'poweredby'			=>	'Powered by Flyspray',

// Added in version 0.9.5

'selectproject'		=>	'Lista dei task per il progetto:',
'show'				=>	'Mostra',
'projects'			=>	'Progetti',
'adminmenu'			=>	'Menu di amministrazione',

// Added in version 0.9.6
'duplicated'		=>	'Azione ripetuta. Redirect alla pagina principale.',
'allprojects'       =>	'Tutti i progetti',
'selectproject'		=>	'per il progettot:',
'tasksall'          =>  'Tutti i task',
'tasksassigned'     =>  'Tasks a me assegnati',
'tasksreported'     =>  'Tasks da me riportati',
'taskswatched'      =>  'Tasks che controllo',
'lastsearch'   =>  'Ultima ricerca',

// Added in version 0.9.7
'adminreqwaiting'   =>   'Richieste ammininstrative',
);
?>
